@@ -201,6 +201,8 @@ class Validation(object):
 
 
     def validate_transmit(payload, config):
+        if config is None:
+            return
         all_flows = []
         for f in config.flows:
             all_flows.append(f.name)
